#!/usr/bin/python

"""
This is the make file for templatelib.

Anything starting with a # or in three quotes is a comment.

Change the first line of this file to point to where your python is installed, or ignore it and run 'python deploy.py' from the command line.
"""

import templatelib

"""
Set how much logging detail you want. Possible values are LOG_DEBUG, LOG_INFO, LOG_ERROR and LOG_FATAL. Default to LOG_INFO
"""
templatelib.loglevel = templatelib.LOG_INFO

"""
Source directory. Where we deploy the site from. This directory should contain your template and include files.
"""
templatelib.srcdir = "/home/myname/mysite"

"""
Destination directory. Where your webserver expects to find HTML pages. In practice you deploy locally, test it, then ftp up to your webspace.
"""
templatelib.dstdir = "/var/www/mysite"

"""
Global variables. The string before the collon is what to search for, the string after it is what to replace it with.
"""
templatelib.GLOBAL_VARS = {
	"title": "darkcoding.net",
	"otherkey": "some string here"
	}

"""
Global files. The string before the collon is what to search for, the string after the collon is a filename (or path and filename) whose contents will be inserted where the tag with the key was.
"""
templatelib.GLOBAL_FILES = {
	"header": "header.inc",
	"otherfile": "file.xyz"
	}

##
## PAGE DEFINITIONS
## Change and add as needed

"""
This is how you define a page. The first argument to Page is the template to use, the second is the file to create.
"""

page = templatelib.Page("main.tpl", "index.html")

"""
The page object has vars and files just like in GLOBAL above. Search order for keys is page.vars, then page.files, then GLOBAL_VARS, then GLOBAL_FILES
"""
page.vars = { "title": "The index page" }
page.files = {"body": "index.inc"}

"""
Every page must be appended to 'templatelib.pages' so that we know to proces it
"""
templatelib.pages.append(page)

##
## STATIC DEPLOYMENT
## Comment in and change as needed

"""
Used to copy a file over. The 1 at the end means assume the first name is in srcdir and the second name will be in dstdir. If not present you have to give full paths.
"""
#templatelib.copy("stylesheet.css", "stylesheet.css", 1)

"""
Create a directory. The 1 means make it a subdirectory of dstdir. If not present you have to give the full path
"""
#templatelib.makedirs("images", 1)

"""
Wildcard copy
"""
#templatelib.copy( "images/*.jpg", "images/", 1) 
#templatelib.copy( "images/*.png", "images/", 1 ) 

"""
Whole directory copy
"""
#templatelib.copy("software", "software/", 1)

"""
If you don't include this last line nothing will happen !!
"""

# Generate !

templatelib.generateall()
